@@ -7,14 +7,13 @@ import org.gcube.portlets.user.td.columnwidget.client.dimension.CodelistSelectio
 import org.gcube.portlets.user.td.columnwidget.client.mapping.ColumnMappingDialog;
 import org.gcube.portlets.user.td.columnwidget.client.mapping.ColumnMappingListProperties;
 import org.gcube.portlets.user.td.columnwidget.client.mapping.ColumnMappingListener;
-import org.gcube.portlets.user.td.columnwidget.client.progress.ChangeColumnTypeProgressDialog;
-import org.gcube.portlets.user.td.columnwidget.client.progress.ProgressDialogListener;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnTypeCodeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.LocaleTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.TimeDimensionTypeProperties;
+import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeElement;
 import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeStore;
 import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeElement;
@@ -29,6 +28,8 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.mapping.ColumnMappingList;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.type.ChangeColumnTypeSession;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
+import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
@@ -47,6 +48,7 @@ import com.google.gwt.event.logical.shared.SelectionEvent;
 import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.web.bindery.event.shared.EventBus;
+import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
 import com.sencha.gxt.cell.core.client.form.ComboBoxCell.TriggerAction;
 import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.data.client.loader.RpcProxy;
@@ -80,8 +82,8 @@ import com.sencha.gxt.widget.core.client.info.Info;
  *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  * 
  */
-public class ChangeColumnTypePanel extends FramedPanel implements
-		CodelistSelectionListener, ColumnMappingListener,  ProgressDialogListener{
+public class ChangeColumnTypePanel extends FramedPanel implements 
+		CodelistSelectionListener, ColumnMappingListener, MonitorDialogListener{
 	protected String WIDTH = "640px";
 	protected String HEIGHT = "520px";
 	protected EventBus eventBus;
@@ -123,7 +125,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 	protected TextButton change;
 
 	protected ChangeColumnTypeSession changeColumnTypeSession;
-	protected ChangeColumnTypeProgressDialog changeColumnTypeProgressDialog;
+	
 
 	public ChangeColumnTypePanel(TRId trId, String columnName, EventBus eventBus) {
 		setWidth(WIDTH);
@@ -373,6 +375,11 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		// Change
 		change = new TextButton("Change");
+		change.setIcon(ResourceBundle.INSTANCE.columnType());
+		change.setIconAlign(IconAlign.RIGHT);
+		change.setTitle("Change Column Type");
+
+		
 		SelectHandler changeHandler = new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -615,7 +622,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 	//TODO
 	protected void updateColumnType(ColumnTypeCode type) {
-		Log.debug("Update ColumnTypeCode " + type.toString());
+		Log.debug("Update ColumnTypeCode: " + type);
 		switch (type) {
 		case CODENAME:
 			comboLocaleTypeLabel.setVisible(true);
@@ -920,7 +927,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 	private void callChangeColumnType() {
 		TDGWTServiceAsync.INSTANCE.startChangeColumnType(
-				changeColumnTypeSession, new AsyncCallback<Void>() {
+				changeColumnTypeSession, new AsyncCallback<String>() {
 					public void onFailure(Throwable caught) {
 						if (caught instanceof TDGWTSessionExpiredException) {
 							eventBus.fireEvent(new SessionExpiredEvent(
@@ -934,9 +941,8 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						}
 					}
 
-					public void onSuccess(Void result) {
-						callChangeColumnTypeProgressDialog();
-						
+					public void onSuccess(String taskId) {
+						openMonitorDialog(taskId);
 						
 					}
 
@@ -1101,13 +1107,13 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		}
 	}
 	
-	
-	protected void callChangeColumnTypeProgressDialog(){
-		changeColumnTypeProgressDialog = new ChangeColumnTypeProgressDialog(
-				eventBus);
-		changeColumnTypeProgressDialog.addProgressDialogListener(this);
-		changeColumnTypeProgressDialog.show();
-	} 
+
+	///
+	protected void openMonitorDialog(String taskId){
+		MonitorDialog monitorDialog=new MonitorDialog(taskId,eventBus);
+		monitorDialog.addProgressDialogListener(this);
+		monitorDialog.show();
+	}
 
 	@Override
 	public void operationComplete(TRId trId) {
@@ -1115,14 +1121,14 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
 				ChangeTableRequestType.CHANGECOLUMNTYPE, trId, why);
 		eventBus.fireEvent(changeTableRequestEvent);
-		close();
-
+		close();	
 	}
 
 	@Override
-	public void operationFailed(Throwable caught, String reason) {
-		UtilsGXT3.alert("Error in Change Column Type", reason);
+	public void operationFailed(Throwable caught, String reason, String details) {
+		UtilsGXT3.alert(reason, details);
 		close();
+		
 	}
 
 	@Override
@@ -1132,8 +1138,21 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				ChangeTableRequestType.CHANGECOLUMNTYPE, trId, why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
+		
 	}
 
+	@Override
+	public void operationAborted() {
+		close();
+		
+	}
+
+	@Override
+	public void operationPutInBackground() {
+		close();
+		
+	}
+	
 	
 
 }
