@@ -5,6 +5,8 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.widget.core.client.Window;
+import com.sencha.gxt.widget.core.client.event.SelectEvent;
+import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
 import com.sencha.gxt.widget.core.client.form.ComboBox;
 
 /**
@@ -34,9 +36,41 @@ public class LabelColumnDialog extends Window {
 		this.trId = trId;
 		this.columnName = columnName;
 		this.eventBus=eventBus;
-		setBodyBorder(false);
+		initWindow();
 		
 		LabelColumnPanel labelColumnPanel= new LabelColumnPanel(trId, columnName, eventBus);
 		add(labelColumnPanel);
 	}
+	
+	protected void initWindow() {
+		setWidth(WIDTH);
+		setHeight(HEIGHT);
+		setBodyBorder(false);
+		setResizable(false);
+		setHeadingText("Label Columns");
+		//getHeader().setIcon(Resources.IMAGES.side_list());
+	}
+	
+	
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	protected void initTools() {
+		super.initTools();
+
+		closeBtn.addSelectHandler(new SelectHandler() {
+
+			public void onSelect(SelectEvent event) {
+				close();
+			}
+		});
+
+	}
+
+	public void close() {
+		hide();
+
+	}
+	
 }
